@@ -1,5 +1,8 @@
 package Selenium::CanStartBinary;
-$Selenium::CanStartBinary::VERSION = '1.20';
+$Selenium::CanStartBinary::VERSION = '1.21';
+use strict;
+use warnings;
+
 # ABSTRACT: Teach a WebDriver how to start its own binary aka no JRE!
 use File::Spec;
 use Selenium::CanStartBinary::ProbePort qw/find_open_port_above find_open_port probe_port/;
@@ -154,7 +157,7 @@ sub BUILDARGS {
     # Since we can't force an order, we introduced try_binary which gets
     # decided during BUILDARGS to tip us off as to whether we should try
     # binary mode or not.
-    my ( $class, %args ) = @_;
+    my ( undef, %args ) = @_;
 
     if ( ! exists $args{remote_server_addr} && ! exists $args{port} ) {
         $args{try_binary} = 1;
@@ -238,7 +241,7 @@ sub shutdown_binary {
         # Tell the binary itself to shutdown
         my $port = $self->port;
         my $ua = $self->ua;
-        my $res = $ua->get('http://127.0.0.1:' . $port . '/wd/hub/shutdown');
+        $ua->get('http://127.0.0.1:' . $port . '/wd/hub/shutdown');
 
         # Close the orphaned command windows on windows
         $self->shutdown_windows_binary;
@@ -263,10 +266,7 @@ sub shutdown_windows_binary {
             # other task to kill.
             return;
         }
-        else {
-            my $kill = 'taskkill /FI "WINDOWTITLE eq ' . $self->window_title . '" > nul 2>&1';
-            system($kill);
-        }
+        system('taskkill /FI "WINDOWTITLE eq ' . $self->window_title . '" > nul 2>&1');
     }
 }
 
@@ -299,8 +299,9 @@ sub _construct_command {
 sub _cmd_prefix {
     my ($self) = @_;
 
+    my $prefix = '';
     if (IS_WIN) {
-        my $prefix = 'start "' . $self->window_title . '"';
+        $prefix = 'start "' . $self->window_title . '"';
 
         if ($self->_is_old_ff) {
             # For older versions of Firefox that run without
@@ -315,9 +316,7 @@ sub _cmd_prefix {
             return $prefix . ' /MIN ';
         }
     }
-    else {
-        return '';
-    }
+    return $prefix;
 }
 
 sub _cmd_suffix {
@@ -347,27 +346,7 @@ Selenium::CanStartBinary - Teach a WebDriver how to start its own binary aka no
 
 =head1 VERSION
 
-version 1.20
-
-=head1 SYNOPSIS
-
-    package My::Selenium::Chrome {
-        use Moo;
-        extends 'Selenium::Remote::Driver';
-
-        has 'binary' => ( is => 'ro', default => 'chromedriver' );
-        has 'binary_port' => ( is => 'ro', default => 9515 );
-        has '_binary_args' => ( is => 'ro', default => sub {
-            return ' --port=' . shift->port . ' --url-base=wd/hub ';
-        });
-        with 'Selenium::CanStartBinary';
-        1
-    };
-
-    my $chrome_via_binary = My::Selenium::Chrome->new;
-    my $chrome_with_path  = My::Selenium::Chrome->new(
-        binary => './chromedriver'
-    );
+version 1.21
 
 =head1 DESCRIPTION
 
@@ -513,6 +492,8 @@ was run to start the webdriver server.
     my $f = Selenium::Firefox->new;
     say $f->_command;
 
+=for Pod::Coverage *EVERYTHING*
+
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
@@ -540,7 +521,7 @@ L<Selenium::PhantomJS|Selenium::PhantomJS>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/gempesaw/Selenium-Remote-Driver/issues
+L<https://github.com/teodesian/Selenium-Remote-Driver/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
