@@ -1,5 +1,8 @@
 package Selenium::InternetExplorer;
-$Selenium::InternetExplorer::VERSION = '1.12';
+$Selenium::InternetExplorer::VERSION = '1.21';
+use strict;
+use warnings;
+
 # ABSTRACT: A convenience package for creating a IE instance
 use Moo;
 extends 'Selenium::Remote::Driver';
@@ -30,7 +33,7 @@ Selenium::InternetExplorer - A convenience package for creating a IE instance
 
 =head1 VERSION
 
-version 1.12
+version 1.21
 
 =head1 SYNOPSIS
 
@@ -72,7 +75,7 @@ L<Selenium::Remote::Driver|Selenium::Remote::Driver>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/gempesaw/Selenium-Remote-Driver/issues
+L<https://github.com/teodesian/Selenium-Remote-Driver/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
